@@ -197,7 +197,23 @@ class TupleTests(TestCase):
 		assert tup1 != list1
 		assert tup2 != tup3
 		assert tup2 != tup4
-		assert list1 != tup1	
+		assert list1 != tup1
+		
+	def test_empty_tuple_success(self):
+		from typecheck import Tuple
+	
+		check_type(Tuple(), tuple())
+	
+	def test_empty_tuple_failure(self):
+		from typecheck import Tuple, _TC_TypeError
+		
+		try:
+			check_type(Tuple(), (5, 6))
+		except _TC_TypeError, e:
+			assert e.wrong == (int, int)
+			assert e.right == ()
+		else:
+			self.fail("Passed incorrectly")
 	
 class SingleType_ListTests(TestCase):
 	def setUp(self):
@@ -539,281 +555,6 @@ class NestedTests(TestCase):
 		else:
 			self.fail("Passed incorrectly")
 			
-	def test_or_lists(self):
-		from typecheck import _TC_TypeError, List, Or
-		
-		def or_type(obj):
-			check_type(Or(List(int), List(float)), obj)
-		
-		or_type( [4,5,6] )
-		or_type( [4.0, 5.0] )
-		
-		try:
-			or_type( ["a", "b"] )
-		except _TC_TypeError, e:
-			assert e.wrong == [str]
-			assert e.right == Or( [int], [float] )
-		else:
-			self.fail("Passed incorrectly")
-			
-	def test_lists_of_ors(self):
-		from typecheck import _TC_IndexError, List, Or
-		from typecheck import _TC_TypeError
-		
-		def or_type(obj):
-			check_type(List( Or(int, float) ), obj)
-		
-		or_type( [4,5,6] )
-		or_type( [4.0, 8, 5.0] )
-		
-		try:
-			or_type( [8, "b"] )
-		except _TC_IndexError, e:
-			assert e.index == 1
-			assert isinstance(e.inner, _TC_TypeError)
-			assert e.inner.wrong == str
-			assert e.inner.right == Or(int, float)
-		else:
-			self.fail("Passed incorrectly")
-			
-	def test_nested_ors_ands(self):
-		from typecheck import _TC_TypeError, Or, And
-		
-		class A: pass
-		class B: pass
-		class C(A, B): pass
-		
-		and_type = And(Or(int, A), B)
-		
-		check_type(and_type, C())
-		
-		try:
-			check_type(and_type, A())
-		except _TC_TypeError, e:
-			assert e.wrong == A
-			assert e.right == And(Or(int, A), B)
-		else:
-			self.fail("Passed incorrectly")
-			
-	def test_dict_of_ors(self):
-		from typecheck import _TC_KeyError, Or, Dict, _TC_TypeError
-		from typecheck import _TC_DictError
-		
-		or_type = Or(int, float)
-		def dict_type(obj):
-			check_type(Dict(or_type, or_type), obj)
-		
-		dict_type( {4:4, 4.0:4, 4:7.0} )
-		
-		try:
-			dict_type( {'f': 5} )
-		except _TC_KeyError, e:
-			assert e.key == 'f'
-			assert isinstance(e.inner, _TC_TypeError)
-			assert e.inner.wrong == str
-			assert e.inner.right == or_type
-		else:
-			self.fail("Passed incorrectly")
-
-class OrTests(TestCase):
-	def setUp(self):
-		from typecheck import Or
-	
-		def or_type(obj):
-			check_type(Or(int, float), obj)
-	
-		self.or_type = or_type
-		
-	def test_success(self):
-		from typecheck import Or
-	
-		self.or_type(5)
-		self.or_type(7.0)
-		
-		class A: pass
-		class B: pass
-		class C(A, B): pass
-			
-		check_type(Or(A, B), C())
-		check_type(Or(A), A())
-		
-	def test_failure(self):
-		from typecheck import _TC_TypeError, Or
-	
-		try:
-			self.or_type("foo")
-		except _TC_TypeError, e:
-			assert e.right == Or(int, float)
-			assert e.wrong == str
-		else:
-			self.fail("Passed incorrectly")
-			
-	def test_equality(self):
-		from typecheck import Or
-		
-		assert Or(int, float) == Or(int, float)
-		assert Or(int, float) == Or(int, int, int, float)
-		assert Or(int, int, int, float) == Or(int, float)
-		assert not Or(int, float) != Or(int, float)
-		assert Or(float, str) != Or(int, float)
-		assert Or(int, float) == Or(int, float, str)
-		assert Or(int, float, str) != Or(int, float)
-		assert Or(int, float) == Or(float, int)
-		assert not Or(int, float) != Or(float, int)
-			
-class AndTests(TestCase):
-	def test_success(self):
-		from typecheck import And
-	
-		class A: pass
-		class B: pass
-		class C(A, B): pass
-			
-		check_type(And(A, B), C())
-		
-	def test_failure(self):
-		from typecheck import _TC_TypeError, And
-	
-		try:
-			check_type(And(int, float), "foo")
-		except _TC_TypeError, e:
-			assert e.right == And(int, float)
-			assert e.wrong == str
-		else:
-			self.fail("Passed incorrectly")
-			
-	def test_equality(self):
-		from typecheck import And
-		
-		assert And(int, float) == And(int, int, int, float)
-		assert And(int, int, int, float) == And(int, float)
-		assert And(int, float) == And(int, float)
-		assert And(int, float) == And(float, int)
-		assert not And(int, float) == And(float, float)
-		assert And(int, float) != And(float, float)
-		assert And(int, float) != And(int, int)
-		assert And(int, float) == And(int, float, str)
-
-class NotTests(TestCase):
-	def test_success(self):
-		from typecheck import Not
-	
-		check_type(Not(int), 4.0)
-		check_type(Not(int, float), 'four')
-		
-		class A: pass
-		class B: pass
-		class C: pass
-			
-		check_type(Not(A, B, int), C())
-		
-	def test_failure_1(self):
-		from typecheck import _TC_TypeError, Not
-	
-		try:
-			check_type(Not(int), 4)
-		except _TC_TypeError, e:
-			assert e.right == Not(int)
-			assert e.wrong == int
-		else:
-			self.fail("Passed incorrectly")
-			
-	def test_failure_2(self):
-		from typecheck import _TC_TypeError, Not
-	
-		try:
-			check_type(Not(int, float), 4.0)
-		except _TC_TypeError, e:
-			assert e.right == Not(int, float)
-			assert e.wrong == float
-		else:
-			self.fail("Passed incorrectly")
-			
-	def test_failure_3(self):
-		from typecheck import _TC_TypeError, Not
-	
-		class A: pass
-		class B: pass
-		class C(A, B): pass
-			
-		try:
-			check_type(Not(A, B, int), C())	
-		except _TC_TypeError, e:
-			assert e.right == Not(A, B, int)
-			assert e.wrong == C
-		else:
-			self.fail("Passed incorrectly")
-			
-	def test_equality(self):
-		from typecheck import Not
-		
-		assert Not(int, int, int) == Not(int)
-		assert Not(int) == Not(int, int, int)
-		assert Not(int) == Not(int)
-		assert not Not(int) == Not(float)
-		assert Not(int) != Not(float)
-		assert Not(int, float) == Not(float, int)
-		assert Not([int], (int, int)) == Not((int, int), [int])
-			
-class EmptyTests(TestCase):
-	def test_list_success(self):
-		from typecheck import Empty
-	
-		check_type(Empty(list), [])
-	
-	def test_list_failure(self):
-		from typecheck import Empty, _TC_LengthError
-		
-		try:
-			check_type(Empty(list), [5, 6])
-		except _TC_LengthError, e:
-			assert e.wrong == 2
-			assert e.right == 0
-		else:
-			self.fail("Passed incorrectly")
-			
-	def test_dict_success(self):
-		from typecheck import Empty
-	
-		check_type(Empty(dict), {})
-	
-	def test_dict_failure(self):
-		from typecheck import Empty, _TC_LengthError, _TC_DictError
-		
-		try:
-			check_type(Empty(dict), {'f': 5})
-		except _TC_DictError, e:
-			assert isinstance(e.inner, _TC_LengthError)
-			assert e.inner.wrong == 1
-			assert e.inner.right == 0
-		else:
-			self.fail("Passed incorrectly")
-			
-	def test_tuple_success(self):
-		from typecheck import Tuple
-	
-		check_type(Tuple(), tuple())
-	
-	def test_tuple_failure(self):
-		from typecheck import Tuple, _TC_TypeError
-		
-		try:
-			check_type(Tuple(), (5, 6))
-		except _TC_TypeError, e:
-			assert e.wrong == (int, int)
-			assert e.right == ()
-		else:
-			self.fail("Passed incorrectly")
-			
-	def test_equality(self):
-		from typecheck import Empty
-		
-		assert Empty(list) == Empty(list)
-		assert Empty(list) != Empty(dict)
-		assert Empty(dict) != Empty(list)
-		assert not Empty(list) != Empty(list)
-		assert not Empty(list) == Empty(dict)
-			
 class ExtensibleSigTests(TestCase):
 	def setUp(self):
 		from typecheck import register_type, _TC_TypeError, unregister_type
