@@ -1566,14 +1566,14 @@ class Test_Self_class(TestCase):
 		from typecheck import typecheck_args, Self
 		
 		class Test(object):
-			@typecheck_args(Self, int, Self)
+			@typecheck_args(Self(), int, Self())
 			def foo(self, a, b):
 				return a, b
 		
 		t = Test()
 		assert Test().foo(4, t) == (4, t)
 		
-		assert Test.foo.type_args_pos == (Self, int, Self)
+		assert Test.foo.type_args_pos == (Self(), int, Self())
 		assert Test.foo.type_args_kw == {}
 		assert Test.foo.type_args_vargs == []
 		assert Test.foo.type_args_kwargs == {}
@@ -1583,11 +1583,11 @@ class Test_Self_class(TestCase):
 		from typecheck import _TC_IndexError, _TC_TypeError
 		
 		class Test(object):
-			@typecheck_args(Self, int, Self)
+			@typecheck_args(Self(), int, Self())
 			def foo(self, a, b):
 				return a, b
 				
-		assert Test.foo.type_args_pos == (Self, int, Self)
+		assert Test.foo.type_args_pos == (Self(), int, Self())
 		assert Test.foo.type_args_kw == {}
 		assert Test.foo.type_args_vargs == []
 		assert Test.foo.type_args_kwargs == {}
@@ -1608,7 +1608,7 @@ class Test_Self_class(TestCase):
 		from typecheck import typecheck_args, Self, TypeSignatureError
 		
 		try:
-			@typecheck_args(Self, int)
+			@typecheck_args(Self(), int)
 			def foo(a, b):
 				return a, b
 		except TypeSignatureError:
@@ -1620,7 +1620,7 @@ class Test_Self_class(TestCase):
 		from typecheck import typecheck_return, Self
 		
 		class Test(object):
-			@typecheck_return(Self, int, Self)
+			@typecheck_return(Self(), int, Self())
 			def foo(self, a, b):
 				return self, a, b
 		
@@ -1628,14 +1628,14 @@ class Test_Self_class(TestCase):
 		t_1 = Test()
 		assert t_1.foo(4, t) == (t_1, 4, t)
 		
-		assert Test.foo.type_return == (Self, int, Self)
+		assert Test.foo.type_return == (Self(), int, Self())
 	
 	def test_self_in_return_fail_1(self):
 		from typecheck import typecheck_return, Self, TypeCheckError
 		from typecheck import _TC_IndexError, _TC_TypeError
 		
 		class Test(object):
-			@typecheck_return(Self, int, Self)
+			@typecheck_return(Self(), int, Self())
 			def foo(self, a, b):
 				return self, a, b
 		
@@ -1651,14 +1651,14 @@ class Test_Self_class(TestCase):
 		else:
 			raise AssertionError("Succeeded incorrectly")
 			
-		assert Test.foo.type_return == (Self, int, Self)
+		assert Test.foo.type_return == (Self(), int, Self())
 		
 	@TODO("Waiting on some way of detecting method-hood in decorators")
 	def test_self_in_return_fail_2(self):
 		from typecheck import typecheck_return, Self, TypeSignatureError
 		
 		try:
-			@typecheck_return(Self, int)
+			@typecheck_return(Self(), int)
 			def foo(self, a, b):
 				return a, b
 		except TypeSignatureError:
@@ -1672,7 +1672,7 @@ class Test_Self_class(TestCase):
 		from typecheck import _TC_IndexError, _TC_TypeError
 		
 		class Test(object):
-			@typecheck_return(Self, int, Self)
+			@typecheck_return(Self(), int, Self())
 			def foo(self, a, b):
 				return a, a, b
 		
@@ -1688,7 +1688,7 @@ class Test_Self_class(TestCase):
 		else:
 			raise AssertionError("Succeeded incorrectly")
 			
-		assert Test.foo.type_return == (Self, int, Self)
+		assert Test.foo.type_return == (Self(), int, Self())
 		
 	def test_self_in_yield_pass(self):
 		from typecheck import typecheck_yield, Self, TypeCheckError
@@ -1696,13 +1696,13 @@ class Test_Self_class(TestCase):
 		from typecheck import _TC_GeneratorError
 		
 		class Test(object):
-			@typecheck_yield(Self, int, Self)
+			@typecheck_yield(Self(), int, Self())
 			def foo(self, a, b):
 				yield self, a, self
 
 		t = Test()
 		assert t.foo(4, 6).next() == (t, 4, t)
-		assert Test.foo.type_yield == (Self, int, Self)
+		assert Test.foo.type_yield == (Self(), int, Self())
 
 	@TODO("Waiting on some way of detecting method-hood in decorators")
 	def test_self_in_yield_fail(self):
@@ -1711,7 +1711,7 @@ class Test_Self_class(TestCase):
 		from typecheck import _TC_GeneratorError
 		
 		class Test(object):
-			@typecheck_yield(Self, int, Self)
+			@typecheck_yield(Self(), int, Self())
 			def foo(self, a, b):
 				yield b, a, b
 		
@@ -1728,7 +1728,7 @@ class Test_Self_class(TestCase):
 		else:
 			raise AssertionError("Succeeded incorrectly")
 			
-		assert Test.foo.type_yield == (Self, int, Self)
+		assert Test.foo.type_yield == (Self(), int, Self())
 		
 	def test_self_in_args_yield_pass(self):
 		from typecheck import typecheck_yield, Self, TypeCheckError
@@ -1736,16 +1736,16 @@ class Test_Self_class(TestCase):
 		from typecheck import _TC_GeneratorError, typecheck_args
 		
 		class Test(object):
-			@typecheck_args(Self, int, int)
-			@typecheck_yield(Self, int, Self)
+			@typecheck_args(Self(), int, int)
+			@typecheck_yield(Self(), int, Self())
 			def foo(self, a, b):
 				yield self, a, self
 
 		t = Test()
 		assert t.foo(4, 6).next() == (t, 4, t)
 		
-		assert Test.foo.type_yield == (Self, int, Self)
-		assert Test.foo.type_args_pos == (Self, int, int)
+		assert Test.foo.type_yield == (Self(), int, Self())
+		assert Test.foo.type_args_pos == (Self(), int, int)
 		assert Test.foo.type_args_kw == {}
 		assert Test.foo.type_args_vargs == []
 		assert Test.foo.type_args_kwargs == {}
@@ -1756,13 +1756,13 @@ class Test_Self_class(TestCase):
 		from typecheck import _TC_GeneratorError, typecheck_args
 		
 		class Test(object):
-			@typecheck_args(Self, int, int)
-			@typecheck_yield(Self, int, Self)
+			@typecheck_args(Self(), int, int)
+			@typecheck_yield(Self(), int, Self())
 			def foo(self, a, b):
 				yield b, a, b
 
-		assert Test.foo.type_yield == (Self, int, Self)
-		assert Test.foo.type_args_pos == (Self, int, int)
+		assert Test.foo.type_yield == (Self(), int, Self())
+		assert Test.foo.type_args_pos == (Self(), int, int)
 		assert Test.foo.type_args_kw == {}
 		assert Test.foo.type_args_vargs == []
 		assert Test.foo.type_args_kwargs == {}
@@ -2578,7 +2578,7 @@ class TypeVariableTests(TestCase):
 		assert TypeVariables._TypeVariables__mapping_stack == []
 		assert TypeVariables._TypeVariables__active_mapping == None
 		assert len(TypeVariables._TypeVariables__gen_mappings) == 0
-
+		
 ### Bookkeeping ###
 if __name__ == '__main__':
 	import __main__
