@@ -104,6 +104,24 @@ class _TC_GeneratorError(_TC_NestedError):
 		bad_obj, start_message = self.inner.format_bad_object(bad_object)
 		message = "At yield #%d: %s" % (self.yield_no, bad_obj)
 		return (message, start_message)
+		
+class _TC_AttrException(_TC_Exception):
+	def __init__(self, attr):
+		_TC_Exception.__init__(self, attr)
+		
+		self.attr = attr
+
+class _TC_AttrError(_TC_AttrException, _TC_NestedError):
+	def __init__(self, attr, inner_exception):
+		_TC_AttrException.__init__(self, attr)
+		_TC_NestedError.__init__(self, inner_exception)
+		
+	def message(self):
+		return ("as for attribute %s" % self.attr) + _TC_NestedError.message(self)
+		
+class _TC_MissingAttrError(_TC_AttrException):
+	def message(self):
+		return "missing attribute %s" % self.attr
 
 ### The following exist to provide detailed TypeSignatureErrors
 class _TS_Exception(Exception):
@@ -604,8 +622,8 @@ class Any(CheckType):
 
 ### Base class for Or() and And()
 class _Boolean(CheckType):
-	def __init__(self, *types):
-		self._types = set([Type(t) for t in types])
+	def __init__(self, type, *types):
+		self._types = set([Type(t) for t in (type,)+types])
 		self.type = self
 		
 	def __eq__(self, other):
@@ -650,9 +668,57 @@ class Not(Or):
 		except _TC_Exception:
 			return
 		raise _TC_TypeError(to_check, self)
+		
+class IsCallable(CheckType):
+	def __init__(self):
+		self.type = self
+		
+	def __str__(self):
+		return "IsCallable()"
+		
+	__repr__ = __str__
+	
+	def __typecheck__(self, func, to_check):
+		if not callable(to_check):
+			raise _TC_TypeError(to_check, 'a callable')
+			
+class HasAttr(CheckType):
+	def __init__(self, set_1, set_2=None):
+		attr_sets = {list: [], dict: {}}
+	
+		for (arg_1, arg_2) in ((set_1, set_2), (set_2, set_1)):
+			for t in (list, dict):
+				if isinstance(arg_1, t):
+					attr_sets[t] = arg_1
+					if isinstance(arg_2, t):
+						raise TypeError("can only have one list and/or one dict")
+						
+		self._attr_types = dict.fromkeys(attr_sets[list], Any())
+		
+		for (attr, typ) in attr_sets[dict].items():
+			self._attr_types[attr] = Type(typ)
+		
+	def __typecheck__(self, func, to_check):
+		for (attr, typ) in self._attr_types.items():
+			if not hasattr(to_check, attr):
+				raise _TC_MissingAttrError(attr)
+				
+			try:
+				check_type(typ, func, getattr(to_check, attr))
+			except _TC_Exception, e:
+				raise _TC_AttrError(attr, e)
+				
+class IsIterable(CheckType):
+	def __init__(self):
+		self.type = self
+		
+	def __typecheck__(self, func, to_check):
+		if not (hasattr(to_check, '__iter__') and callable(to_check.__iter__)):
+			raise _TC_TypeError(to_check, "an iterable")
 
 # The current implementation of Self relies on the TypeVariables machinery
-Self = 'this is the class of the invocant'
+def Self():
+	return 'this is the class of the invocant'
 
 ### This is the public side of the module
 #########################################
